svn commit: samba r11227 - branches/SAMBA_3_0/source/registry branches/SAMBA_3_0/source/utils trunk/source/registry trunk/source/utils

jerry at samba.org jerry at samba.org
Thu Oct 20 14:29:24 GMT 2005


Author: jerry
Date: 2005-10-20 14:29:24 +0000 (Thu, 20 Oct 2005)
New Revision: 11227

WebSVN: http://websvn.samba.org/cgi-bin/viewcvs.cgi?view=rev&root=samba&rev=11227

Log:
patch from brian moran to fix typo in eventlog message file registry value name
Modified:
   branches/SAMBA_3_0/source/registry/reg_eventlog.c
   branches/SAMBA_3_0/source/utils/eventlogadm.c
   trunk/source/registry/reg_eventlog.c
   trunk/source/utils/eventlogadm.c


Changeset:
Modified: branches/SAMBA_3_0/source/registry/reg_eventlog.c
===================================================================
--- branches/SAMBA_3_0/source/utils/eventlogadm.c	2005-10-20 13:11:06 UTC (rev 11226)
+++ branches/SAMBA_3_0/source/utils/eventlogadm.c	2005-10-20 14:29:24 UTC (rev 11227)
@@ -61,7 +61,7 @@
 
 	if ( argc < 3 ) {
 		printf( "need more arguments:\n" );
-		printf( "-o addsource EventlogName SourceName /path/to/eventlogmsg.dll\n" );
+		printf( "-o addsource EventlogName SourceName /path/to/EventMessageFile.dll\n" );
 		return -1;
 	}
 	/* must open the registry before we access it */

Modified: trunk/source/registry/reg_eventlog.c
===================================================================
--- trunk/source/utils/eventlogadm.c	2005-10-20 13:11:06 UTC (rev 11226)
+++ trunk/source/utils/eventlogadm.c	2005-10-20 14:29:24 UTC (rev 11227)
@@ -61,7 +61,7 @@
 
 	if ( argc < 3 ) {
 		printf( "need more arguments:\n" );
-		printf( "-o addsource EventlogName SourceName /path/to/eventlogmsg.dll\n" );
+		printf( "-o addsource EventlogName SourceName /path/to/EventMessageFile.dll\n" );
 		return -1;
 	}
 	/* must open the registry before we access it */



More information about the samba-cvs mailing list
--- branches/SAMBA_3_0/source/registry/reg_eventlog.c	2005-10-20 13:11:06 UTC (rev 11226)
+++ branches/SAMBA_3_0/source/registry/reg_eventlog.c	2005-10-20 14:29:24 UTC (rev 11227)
@@ -301,7 +301,7 @@
 	}
 	TALLOC_FREE( subkeys );
 
 	/* at this point KEY_EVENTLOG/<eventlog>/<sourcename> key is in there. Now need to add EventLogMessageFile */
 
 	/* now allocate room for the source's subkeys */
 
@@ -320,14 +320,14 @@
 		return False;
 	}
 	DEBUG( 5,
-	       ( "Storing EventLogMessageFile [%s] to eventlog path of [%s]\n",
+	       ( "Storing EventMessageFile [%s] to eventlog path of [%s]\n",
 		 messagefile, evtlogpath ) );
 
 	regdb_fetch_values( evtlogpath, values );
 
 	init_unistr2( &data, messagefile, UNI_STR_TERMINATE );
 
-	regval_ctr_addvalue( values, "EventLogMessageFile", REG_EXPAND_SZ,
+	regval_ctr_addvalue( values, "EventMessageFile", REG_SZ,
 			     ( char * ) data.buffer,
 			     data.uni_str_len * sizeof( uint16 ) );
 	regdb_store_values( evtlogpath, values );
@@ -301,7 +301,7 @@
 	TALLOC_FREE( subkeys );
 
-	/* at this point KEY_EVENTLOG/<eventlog>/<sourcename> key is in there. Now need to add EventLogMessageFile */
+	/* at this point KEY_EVENTLOG/<eventlog>/<sourcename> key is in there. Now need to add EventMessageFile */
 
 	/* now allocate room for the source's subkeys */

Modified: branches/SAMBA_3_0/source/utils/eventlogadm.c
===================================================================
--- trunk/source/registry/reg_eventlog.c	2005-10-20 13:11:06 UTC (rev 11226)
+++ trunk/source/registry/reg_eventlog.c	2005-10-20 14:29:24 UTC (rev 11227)
@@ -301,7 +301,7 @@
 	}
 	TALLOC_FREE( subkeys );
 
 	/* at this point KEY_EVENTLOG/<eventlog>/<sourcename> key is in there. Now need to add EventLogMessageFile */
 
 	/* now allocate room for the source's subkeys */
 
@@ -320,14 +320,14 @@
 		return False;
 	}
 	DEBUG( 5,
-	       ( "Storing EventLogMessageFile [%s] to eventlog path of [%s]\n",
+	       ( "Storing EventMessageFile [%s] to eventlog path of [%s]\n",
 		 messagefile, evtlogpath ) );
 
 	regdb_fetch_values( evtlogpath, values );
 
 	init_unistr2( &data, messagefile, UNI_STR_TERMINATE );
 
-	regval_ctr_addvalue( values, "EventLogMessageFile", REG_EXPAND_SZ,
+	regval_ctr_addvalue( values, "EventMessageFile", REG_SZ,
 			     ( char * ) data.buffer,
 			     data.uni_str_len * sizeof( uint16 ) );
 	regdb_store_values( evtlogpath, values );
@@ -301,7 +301,7 @@
 	TALLOC_FREE( subkeys );
 
-	/* at this point KEY_EVENTLOG/<eventlog>/<sourcename> key is in there. Now need to add EventLogMessageFile */
+	/* at this point KEY_EVENTLOG/<eventlog>/<sourcename> key is in there. Now need to add EventMessageFile */
 
 	/* now allocate room for the source's subkeys */

Modified: trunk/source/utils/eventlogadm.c
===================================================================